@@ -30,7 +30,13 @@ func getAllOutputConstructors() (map[string]output.Constructor, error) {
 			return nil, errors.New("the kafka output was deprecated in k6 v0.32.0 and removed in k6 v0.34.0, " +
 				"please use the new xk6 kafka output extension instead - https://github.com/k6io/xk6-output-kafka")
 		},
-		"statsd": statsd.New,
+		"statsd": func(params output.Params) (output.Output, error) {
+			params.Logger.Warn("The statsd output is deprecated, and will be removed in a future k6 version. " +
+				"Please use the new xk6 statsd output extension instead. " +
+				"It can be found at https://github.com/LeonAdato/xk6-output-statsd and " +
+				"more info at https://github.com/grafana/k6/issues/2982.")
+			return statsd.New(params)
+		},
 		"datadog": func(params output.Params) (output.Output, error) {
 			return nil, errors.New("the datadog output was deprecated in k6 v0.32.0 and removed in k6 v0.34.0, " +
 				"please use the statsd output with env. variable K6_STATSD_ENABLE_TAGS=true instead")
