@@ -4,9 +4,10 @@ import (
 	"github.com/spf13/cobra"
 
 	"go.k6.io/k6/api/v1/client"
+	"go.k6.io/k6/cmd/state"
 )
 
-func getCmdStats(globalState *globalState) *cobra.Command {
+func getCmdStats(gs *state.GlobalState) *cobra.Command {
 	// statsCmd represents the stats command
 	statsCmd := &cobra.Command{
 		Use:   "stats",
@@ -15,16 +16,16 @@ func getCmdStats(globalState *globalState) *cobra.Command {
 
   Use the global --address flag to specify the URL to the API server.`,
 		RunE: func(cmd *cobra.Command, args []string) error {
-			c, err := client.New(globalState.flags.address)
+			c, err := client.New(gs.Flags.Address)
 			if err != nil {
 				return err
 			}
-			metrics, err := c.Metrics(globalState.ctx)
+			metrics, err := c.Metrics(gs.Ctx)
 			if err != nil {
 				return err
 			}
 
-			return yamlPrint(globalState.stdOut, metrics)
+			return yamlPrint(gs.Stdout, metrics)
 		},
 	}
 	return statsCmd
