@@ -10,6 +10,7 @@ import (
 
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/js/modulestest"
+	"go.k6.io/k6/lib"
 	"go.k6.io/k6/metrics"
 )
 
@@ -76,7 +77,9 @@ func getTestModuleInstance(t testing.TB) (*goja.Runtime, *ModuleInstance) {
 	mockVU := &modulestest.VU{
 		RuntimeField: rt,
 		InitEnvField: &common.InitEnvironment{
-			Registry: metrics.NewRegistry(),
+			TestPreInitState: &lib.TestPreInitState{
+				Registry: metrics.NewRegistry(),
+			},
 		},
 		CtxField:   ctx,
 		StateField: nil,
@@ -420,10 +423,10 @@ func TestParseHTML(t *testing.T) {
 			_, err := rt.RunString(`
 				const values = doc
 					.find("#select_multi option")
-					.map(function(idx, val) { 
+					.map(function(idx, val) {
 						return val.text()
 					})
-				
+
 				if (values.length !== 3) {
 					throw new Error('Expected 3 values, got ' + values.length)
 				}
@@ -477,25 +480,25 @@ func TestParseHTML(t *testing.T) {
 					})
 					return bucketObj
 				})
-		
+
 			if (buckets.length !== 2) {
 				throw new Error('Expected 2 buckets, got ' + buckets.length)
 			}
-		
+
 			if (buckets[0].name !== 'firstBucket') {
 				throw new Error('Expected bucket name to be "firstBucket", got ' + buckets[0].name)
 			}
-		
+
 			if (buckets[0].creationDate !== 1654852823) {
 				throw new Error(
 					'Expected bucket creation date to be 1654852823, got ' + buckets[0].creationDate
 				)
 			}
-		
+
 			if (buckets[1].name != 'secondBucket') {
 				throw new Error('Expected bucket name to be "secondBucket", got ' + buckets[1].name)
 			}
-		
+
 			if (buckets[1].creationDate !== 1654852825) {
 				throw new Error(
 					'Expected bucket creation date to be 1654852825, got ' + buckets[1].creationDate
