@@ -13,13 +13,13 @@ import (
 	"go/build"
 	"io"
 	"io/fs"
-	"io/ioutil"
 	stdlog "log"
 	"math/big"
 	"net"
 	"net/http"
 	"net/http/httptest"
 	"net/url"
+	"os"
 	"strings"
 	"sync"
 	"testing"
@@ -47,7 +47,6 @@ import (
 	"go.k6.io/k6/lib/testutils/mockoutput"
 	"go.k6.io/k6/lib/types"
 	"go.k6.io/k6/metrics"
-	"go.k6.io/k6/metrics/engine"
 	"go.k6.io/k6/output"
 )
 
@@ -387,23 +386,17 @@ func TestDataIsolation(t *testing.T) {
 	execScheduler, err := execution.NewScheduler(testRunState)
 	require.NoError(t, err)
 
-	metricsEngine, err := engine.NewMetricsEngine(testRunState)
-	require.NoError(t, err)
-
 	globalCtx, globalCancel := context.WithCancel(context.Background())
 	defer globalCancel()
 	runCtx, runAbort := execution.NewTestRunContext(globalCtx, testRunState.Logger)
 
 	mockOutput := mockoutput.New()
-	outputManager := output.NewManager([]output.Output{mockOutput, metricsEngine.CreateIngester()}, testRunState.Logger, runAbort)
+	outputManager := output.NewManager([]output.Output{mockOutput}, testRunState.Logger, runAbort)
 	samples := make(chan metrics.SampleContainer, 1000)
 	waitForMetricsFlushed, stopOutputs, err := outputManager.Start(samples)
 	require.NoError(t, err)
 	defer stopOutputs(nil)
 
-	finalizeThresholds := metricsEngine.StartThresholdCalculations(runAbort, execScheduler.GetState().GetCurrentTestRunDuration)
-	require.Nil(t, finalizeThresholds)
-
 	require.Empty(t, runner.defaultGroup.Groups)
 
 	stopEmission, err := execScheduler.Init(runCtx, samples)
@@ -2408,7 +2401,7 @@ func TestComplicatedFileImportsForGRPC(t *testing.T) {
 	}
 
 	fs := fsext.NewMemMapFs()
-	protoFile, err := ioutil.ReadFile("../lib/testutils/httpmultibin/grpc_testing/test.proto")
+	protoFile, err := os.ReadFile("../lib/testutils/httpmultibin/grpc_testing/test.proto") //nolint:forbidigo
 	require.NoError(t, err)
 	require.NoError(t, fsext.WriteFile(fs, "/path/to/service.proto", protoFile, 0o644))
 	require.NoError(t, fsext.WriteFile(fs, "/path/to/same-dir.proto", []byte(
