@@ -224,6 +224,11 @@ var (
 		"test/built-ins/Object/prototype/__define", // AnnexB defineGetter defineSetter
 
 		"test/language/expressions/dynamic-import", // not supported
+
+		// Go 1.16 only supports unicode 13; While go 1.21 has support for this - we disable them
+		// so that they aren't flaky between versions.
+		"test/language/identifiers/start-unicode-14.",
+		"test/language/identifiers/part-unicode-14.",
 	}
 )
 
@@ -284,7 +289,7 @@ func parseTC39File(name string) (*tc39Meta, string, error) {
 	if err != nil {
 		return nil, "", err
 	}
-	defer f.Close() //nolint:errcheck,gosec
+	defer f.Close() //nolint:errcheck
 
 	b, err := io.ReadAll(f)
 	if err != nil {
@@ -586,7 +591,7 @@ func (ctx *tc39TestCtx) compile(base, name string) (*goja.Program, error) {
 		if err != nil {
 			return nil, err
 		}
-		defer f.Close() //nolint:gosec,errcheck
+		defer f.Close() //nolint:errcheck
 
 		b, err := io.ReadAll(f)
 		if err != nil {
