@@ -9,17 +9,17 @@ import (
 // MockResolver implements netext.Resolver, and allows changing the host
 // mapping at runtime.
 type MockResolver struct {
-	m        sync.RWMutex
-	hosts    map[string][]net.IP
-	fallback func(host string) ([]net.IP, error)
+	m           sync.RWMutex
+	hosts       map[string][]net.IP
+	ResolveHook func(host string, result []net.IP)
 }
 
 // New returns a new MockResolver.
-func New(hosts map[string][]net.IP, fallback func(host string) ([]net.IP, error)) *MockResolver {
+func New(hosts map[string][]net.IP) *MockResolver {
 	if hosts == nil {
 		hosts = make(map[string][]net.IP)
 	}
-	return &MockResolver{hosts: hosts, fallback: fallback}
+	return &MockResolver{hosts: hosts}
 }
 
 // LookupIP returns the first IP mapped for host.
@@ -34,15 +34,17 @@ func (r *MockResolver) LookupIP(host string) (net.IP, error) {
 
 // LookupIPAll returns all IPs mapped for host. It mimics the net.LookupIP
 // signature so that it can be used to mock netext.LookupIP in tests.
-func (r *MockResolver) LookupIPAll(host string) ([]net.IP, error) {
+func (r *MockResolver) LookupIPAll(host string) (ips []net.IP, err error) {
+	defer func() {
+		if r.ResolveHook != nil {
+			r.ResolveHook(host, ips)
+		}
+	}()
 	r.m.RLock()
 	defer r.m.RUnlock()
 	if ips, ok := r.hosts[host]; ok {
 		return ips, nil
 	}
-	if r.fallback != nil {
-		return r.fallback(host)
-	}
 	return nil, fmt.Errorf("lookup %s: no such host", host)
 }
 
