@@ -8,10 +8,10 @@ import (
 	"testing"
 
 	"github.com/sirupsen/logrus"
-	"github.com/spf13/afero"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"go.k6.io/k6/lib/fsext"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/lib/testutils/httpmultibin"
 	"go.k6.io/k6/loader"
@@ -138,10 +138,10 @@ func TestLoad(t *testing.T) {
 				moduleURL, err := loader.Resolve(pwdURL, data.path)
 				require.NoError(t, err)
 
-				filesystems := make(map[string]afero.Fs)
-				filesystems["file"] = afero.NewMemMapFs()
+				filesystems := make(map[string]fsext.Fs)
+				filesystems["file"] = fsext.NewMemMapFs()
 				assert.NoError(t, filesystems["file"].MkdirAll("/path/to", 0o755))
-				assert.NoError(t, afero.WriteFile(filesystems["file"], "/path/to/file.txt", []byte("hi"), 0o644))
+				assert.NoError(t, fsext.WriteFile(filesystems["file"], "/path/to/file.txt", []byte("hi"), 0o644))
 				src, err := loader.Load(logger, filesystems, moduleURL, data.path)
 				require.NoError(t, err)
 
@@ -152,10 +152,10 @@ func TestLoad(t *testing.T) {
 
 		t.Run("Nonexistent", func(t *testing.T) {
 			t.Parallel()
-			filesystems := make(map[string]afero.Fs)
-			filesystems["file"] = afero.NewMemMapFs()
+			filesystems := make(map[string]fsext.Fs)
+			filesystems["file"] = fsext.NewMemMapFs()
 			assert.NoError(t, filesystems["file"].MkdirAll("/path/to", 0o755))
-			assert.NoError(t, afero.WriteFile(filesystems["file"], "/path/to/file.txt", []byte("hi"), 0o644))
+			assert.NoError(t, fsext.WriteFile(filesystems["file"], "/path/to/file.txt", []byte("hi"), 0o644))
 
 			root, err := url.Parse("file:///")
 			require.NoError(t, err)
@@ -176,7 +176,7 @@ func TestLoad(t *testing.T) {
 		t.Parallel()
 		t.Run("From local", func(t *testing.T) {
 			t.Parallel()
-			filesystems := map[string]afero.Fs{"https": afero.NewMemMapFs()}
+			filesystems := map[string]fsext.Fs{"https": fsext.NewMemMapFs()}
 			root, err := url.Parse("file:///")
 			require.NoError(t, err)
 
@@ -192,7 +192,7 @@ func TestLoad(t *testing.T) {
 
 		t.Run("Absolute", func(t *testing.T) {
 			t.Parallel()
-			filesystems := map[string]afero.Fs{"https": afero.NewMemMapFs()}
+			filesystems := map[string]fsext.Fs{"https": fsext.NewMemMapFs()}
 			pwdURL, err := url.Parse(sr("HTTPSBIN_URL"))
 			require.NoError(t, err)
 
@@ -208,7 +208,7 @@ func TestLoad(t *testing.T) {
 
 		t.Run("Relative", func(t *testing.T) {
 			t.Parallel()
-			filesystems := map[string]afero.Fs{"https": afero.NewMemMapFs()}
+			filesystems := map[string]fsext.Fs{"https": fsext.NewMemMapFs()}
 			pwdURL, err := url.Parse(sr("HTTPSBIN_URL"))
 			require.NoError(t, err)
 
@@ -232,7 +232,7 @@ func TestLoad(t *testing.T) {
 		moduleSpecifierURL, err := loader.Resolve(root, moduleSpecifier)
 		require.NoError(t, err)
 
-		filesystems := map[string]afero.Fs{"https": afero.NewMemMapFs()}
+		filesystems := map[string]fsext.Fs{"https": fsext.NewMemMapFs()}
 		src, err := loader.Load(logger, filesystems, moduleSpecifierURL, moduleSpecifier)
 
 		require.NoError(t, err)
@@ -259,7 +259,7 @@ func TestLoad(t *testing.T) {
 			{"HOST", "some-path-that-doesnt-exist.js"},
 		}
 
-		filesystems := map[string]afero.Fs{"https": afero.NewMemMapFs()}
+		filesystems := map[string]fsext.Fs{"https": fsext.NewMemMapFs()}
 		for _, data := range testData {
 			moduleSpecifier := data.moduleSpecifier
 			t.Run(data.name, func(t *testing.T) {
