@@ -19,6 +19,7 @@ import (
 type lokiHook struct {
 	fallbackLogger logrus.FieldLogger
 	addr           string
+	headers        [][2]string
 	labels         [][2]string
 	ch             chan *logrus.Entry
 	limit          int
@@ -124,6 +125,11 @@ func (h *lokiHook) parseArgs(line string) error {
 				labelKey := strings.TrimPrefix(key, "label.")
 				h.labels = append(h.labels, [2]string{labelKey, value})
 
+				continue
+			} else if strings.HasPrefix(key, "header.") {
+				headerKey := strings.TrimPrefix(key, "header.")
+				h.headers = append(h.headers, [2]string{headerKey, value})
+
 				continue
 			}
 
@@ -150,10 +156,13 @@ func (h *lokiHook) Listen(ctx context.Context) {
 		pushCh     = make(chan chan int64)
 	)
 
+	pushDone := make(chan struct{})
+	defer func() { <-pushDone }()
 	defer ticker.Stop()
 	defer close(pushCh)
 
 	go func() {
+		defer close(pushDone)
 		oldLogs := make([]tmpMsg, 0, h.limit*2)
 		for ch := range pushCh {
 			msgsToPush, msgs = msgs, msgsToPush
@@ -333,6 +342,10 @@ func (h *lokiHook) push(b bytes.Buffer) error {
 
 	req.Header.Set("Content-Type", "application/json")
 
+	for _, header := range h.headers {
+		req.Header.Add(header[0], header[1])
+	}
+
 	res, err := h.client.Do(req)
 
 	if res != nil {
