@@ -19,7 +19,7 @@ func TestNewSink(t *testing.T) {
 		{mt: Counter, sink: &CounterSink{}},
 		{mt: Gauge, sink: &GaugeSink{}},
 		{mt: Rate, sink: &RateSink{}},
-		{mt: Trend, sink: &TrendSink{}},
+		{mt: Trend, sink: NewTrendSink()},
 	}
 	for _, tc := range tests {
 		assert.Equal(t, tc.sink, NewSink(tc.mt))
@@ -101,56 +101,56 @@ func TestTrendSink(t *testing.T) {
 		t.Run("one value", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: 7.0})
-			assert.Equal(t, uint64(1), sink.Count)
-			assert.Equal(t, 7.0, sink.Min)
-			assert.Equal(t, 7.0, sink.Max)
-			assert.Equal(t, 7.0, sink.Avg)
-			assert.Equal(t, 7.0, sink.Sum)
-			assert.Equal(t, []float64{7.0}, sink.Values)
+			assert.Equal(t, uint64(1), sink.Count())
+			assert.Equal(t, 7.0, sink.Min())
+			assert.Equal(t, 7.0, sink.Max())
+			assert.Equal(t, 7.0, sink.Avg())
+			assert.Equal(t, 7.0, sink.Total())
+			assert.Equal(t, []float64{7.0}, sink.values)
 		})
 		t.Run("values", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			for _, s := range unsortedSamples10 {
 				sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: s})
 			}
-			assert.Equal(t, uint64(len(unsortedSamples10)), sink.Count)
-			assert.Equal(t, 0.0, sink.Min)
-			assert.Equal(t, 100.0, sink.Max)
-			assert.Equal(t, 54.0, sink.Avg)
-			assert.Equal(t, 540.0, sink.Sum)
-			assert.Equal(t, unsortedSamples10, sink.Values)
+			assert.Equal(t, uint64(len(unsortedSamples10)), sink.Count())
+			assert.Equal(t, 0.0, sink.Min())
+			assert.Equal(t, 100.0, sink.Max())
+			assert.Equal(t, 54.0, sink.Avg())
+			assert.Equal(t, 540.0, sink.Total())
+			assert.Equal(t, unsortedSamples10, sink.values)
 		})
 		t.Run("negative", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			for _, s := range []float64{-10, -20} {
 				sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: s})
 			}
-			assert.Equal(t, uint64(2), sink.Count)
-			assert.Equal(t, -20.0, sink.Min)
-			assert.Equal(t, -10.0, sink.Max)
-			assert.Equal(t, -15.0, sink.Avg)
-			assert.Equal(t, -30.0, sink.Sum)
-			assert.Equal(t, []float64{-10, -20}, sink.Values)
+			assert.Equal(t, uint64(2), sink.Count())
+			assert.Equal(t, -20.0, sink.Min())
+			assert.Equal(t, -10.0, sink.Max())
+			assert.Equal(t, -15.0, sink.Avg())
+			assert.Equal(t, -30.0, sink.Total())
+			assert.Equal(t, []float64{-10, -20}, sink.values)
 		})
 		t.Run("mixed", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			for _, s := range []float64{1.4, 0, -1.2} {
 				sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: s})
 			}
-			assert.Equal(t, uint64(3), sink.Count)
-			assert.Equal(t, -1.2, sink.Min)
-			assert.Equal(t, 1.4, sink.Max)
-			assert.Equal(t, 0.067, math.Round(sink.Avg*1000)/1000)
-			assert.Equal(t, 0.199, math.Floor(sink.Sum*1000)/1000)
-			assert.Equal(t, []float64{1.4, 0, -1.2}, sink.Values)
+			assert.Equal(t, uint64(3), sink.Count())
+			assert.Equal(t, -1.2, sink.Min())
+			assert.Equal(t, 1.4, sink.Max())
+			assert.Equal(t, 0.067, math.Round(sink.Avg()*1000)/1000)
+			assert.Equal(t, 0.199, math.Floor(sink.Total()*1000)/1000)
+			assert.Equal(t, []float64{1.4, 0, -1.2}, sink.values)
 		})
 	})
 
@@ -159,7 +159,7 @@ func TestTrendSink(t *testing.T) {
 		t.Run("no values", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			for i := 1; i <= 100; i++ {
 				assert.Equal(t, 0.0, sink.P(float64(i)/100.0))
 			}
@@ -167,7 +167,7 @@ func TestTrendSink(t *testing.T) {
 		t.Run("one value", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: 10.0})
 			for i := 1; i <= 100; i++ {
 				assert.Equal(t, 10.0, sink.P(float64(i)/100.0))
@@ -176,7 +176,7 @@ func TestTrendSink(t *testing.T) {
 		t.Run("two values", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: 5.0})
 			sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: 10.0})
 			assert.Equal(t, false, sink.sorted)
@@ -190,7 +190,7 @@ func TestTrendSink(t *testing.T) {
 		t.Run("more than 2", func(t *testing.T) {
 			t.Parallel()
 
-			sink := TrendSink{}
+			sink := NewTrendSink()
 			for _, s := range unsortedSamples10 {
 				sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: s})
 			}
@@ -205,7 +205,7 @@ func TestTrendSink(t *testing.T) {
 	t.Run("format", func(t *testing.T) {
 		t.Parallel()
 
-		sink := TrendSink{}
+		sink := NewTrendSink()
 		for _, s := range unsortedSamples10 {
 			sink.Add(Sample{TimeSeries: TimeSeries{Metric: &Metric{}}, Value: s})
 		}
@@ -259,13 +259,3 @@ func TestRateSink(t *testing.T) {
 		assert.Equal(t, map[string]float64{"rate": 0.5}, sink.Format(0))
 	})
 }
-
-func TestDummySinkAddPanics(t *testing.T) {
-	assert.Panics(t, func() {
-		DummySink{}.Add(Sample{})
-	})
-}
-
-func TestDummySinkFormatReturnsItself(t *testing.T) {
-	assert.Equal(t, map[string]float64{"a": 1}, DummySink{"a": 1}.Format(0))
-}
